function [tab_final]=RotDif_demo2(freq,r1,r2,r3,NH,reslist,init_ax)
%------------------------------------------------------------------
%   ow-2002-University of Maryland
%   based on the program r2r1fit from david fushman
%
%
%   Optimization of isotropic, axially symmetric and fully anisotropic model
%   
%   freq : frequency 
%   r1,r2,r3 : R1, R2, NOE
%   output : name of output file
%
%   guessMC_ax : 1*8 array containing boundary conditions to simulate starting 
%                 guess prior to data fitting  (axially symmetric case),and boundary conditions
%                  (used in the fitting procedure for axially symmetric case) 
%   [lower bound for TAUx,upper bound for TAUX,lower bound for D/D,.....alpha,....beta]
%
%
%
%	CALL: RotDif(freq,r1,r2,r3,NH,reslist,output,mc_max,niter,guessMC_ax,guessMC_full)
%	      
%   mc_max : number of MC step for error calculation (default=1000)
%   niter : number of simulated starting guess prior to optimization(default=50)
%
%   guessMC_ax=[lower bound_TAUx,upper bound_TAUx,lb_D/D,ub_D/D,lb_alpha,ub_alpha,lb_beta,ub_beta]
%   bound_ax=[lower bound_TAUx,lb_D/D,lb_alpha,lb_beta,ub_TAUx,ub_D/D,ub_alpha,ub_beta]
%
%   bound_full=same as bound_ax for Dxx, Dyy, Dzz, alpha, beta, gamma ----> 1*12 array
%   guessMC_full= same as guessMC_ax for Dxx, Dyy, Dzz, alpha, beta, gamma ----> 1*12 array
%
%
%
%------------------------------------------------------------------
format compact
%--------check input, set some params-------





wN=freq*(2710.5/26750)*2*pi/1000;
wNfull=freq*0.1013756*2*pi*1.e06;
flag_case=0;     %check for axially symmetric or fully anisotropic case

bound_full=[0.5 12.0 0.5 12.0 0.5 12.0 0.0 pi 0.0 pi 0.0 pi];
bound_ax=[1.0 15.0 1.0 1.8 0.0 pi 0.0 pi];





%------------check output-------------------
if nargout>=4, kmap=1; else kmap=0; end
sdzres=NaN*ones(1,4);
%----------prepare working set of data-----------
[ratio,sigma,vcoor,rlist]=r2r1prep(r2,r1,NH,reslist,r3);
nres=length(ratio);
dfiso=nres-1;     %degree of freedom isotropic case
df=nres-4;        %degree of freedom axially symmetric
df_full=nres-6;   %degree of freedom fully anisotropic










%----- bounding conditions in the fitting procedure-------

lb=[bound_ax(1) bound_ax(3) bound_ax(5) bound_ax(7)]; %lower bound for TAUc D/D alpha beta
ub=[bound_ax(2) bound_ax(4) bound_ax(6) bound_ax(8)];   %upper bound for TAUc D/D alpha beta


%----- Fitting procedure ---------------------------------
  
    options=optimset('TolX',1.e-10,'TolFun',1e-10,'MaxIter',8000,'maxFunEvals',20000,'LargeScale','on','LevenbergMarquardt','on');


%----begin the MC search-------
 x_ax=lsqnonlin(@rho2,init_ax(1,:),lb,ub,options,ratio,sigma,vcoor,wN); %---- LVM algorithm----- 
    
         

%----- calculate Dxx, Dyy, Dzz -------
endDx=calcDx(x_ax(1));
endDz=calc_Dz(x_ax(2),x_ax(1));



tab_final=[x_ax(1),x_ax(2),endDx,endDz,x_ax(3),x_ax(4)];


%----- visualise points ---------------------




return

%===================================================================






